PALM-meteo: palmmeteo_stdplugins.synthetic.ProfileInterpolator Class Reference

PALM-meteo

Public Member Functions | Public Attributes | List of all members
palmmeteo_stdplugins.synthetic.ProfileInterpolator Class Reference

## Public Member Functions
def | __init__ (self, varname, vc)
def | get_vinterp (self, terrain_ratio, gp0, t0, p_surf, p_trans)
def | interp_next_time (self, dt)

## Public Attributes
| heights
| cur_id
| cur_dt
| next_dt
| delta
| times
| prof
| is_wind
| is_zstag
| vinterpolator

## Constructor & Destructor Documentation

## ◆ __init__()

def palmmeteo_stdplugins.synthetic.ProfileInterpolator.__init__ | ( |  | self,
|  |  | varname,
|  |  | vc
| ) |  |

## Member Function Documentation

## ◆ get_vinterp()

def palmmeteo_stdplugins.synthetic.ProfileInterpolator.get_vinterp | ( |  | self,
|  |  | terrain_ratio,
|  |  | gp0,
|  |  | t0,
|  |  | p_surf,
|  |  | p_trans
| ) |  |

## ◆ interp_next_time()

def palmmeteo_stdplugins.synthetic.ProfileInterpolator.interp_next_time | ( |  | self,
|  |  | dt
| ) |  |

## Member Data Documentation

## ◆ cur_dt

palmmeteo_stdplugins.synthetic.ProfileInterpolator.cur_dt

## ◆ cur_id

palmmeteo_stdplugins.synthetic.ProfileInterpolator.cur_id

## ◆ delta

palmmeteo_stdplugins.synthetic.ProfileInterpolator.delta

## ◆ heights

palmmeteo_stdplugins.synthetic.ProfileInterpolator.heights

## ◆ is_wind

palmmeteo_stdplugins.synthetic.ProfileInterpolator.is_wind

## ◆ is_zstag

palmmeteo_stdplugins.synthetic.ProfileInterpolator.is_zstag

## ◆ next_dt

palmmeteo_stdplugins.synthetic.ProfileInterpolator.next_dt

## ◆ prof

palmmeteo_stdplugins.synthetic.ProfileInterpolator.prof

## ◆ times

palmmeteo_stdplugins.synthetic.ProfileInterpolator.times

## ◆ vinterpolator

palmmeteo_stdplugins.synthetic.ProfileInterpolator.vinterpolator

The documentation for this class was generated from the following file:

- palmmeteo_stdplugins/synthetic.py